@@ -1,10 +1,10 @@
 #include "displayserver_linux.h"
+#include "common/io/io.h"
 #include "common/properties.h"
 #include "util/stringUtils.h"
 #include "util/mallocHelper.h"
 
 #include <stdlib.h>
-#include <ctype.h>
 #include <string.h>
 #include <unistd.h>
 
@@ -12,8 +12,8 @@
     #include <sys/sysctl.h>
     #include <sys/types.h>
     #include <sys/user.h>
-#else
-    #include "common/io/io.h"
+#elif defined(__sun)
+    #include <procfs.h>
 #endif
 
 static const char* parseEnv(void)
@@ -44,7 +44,7 @@ static const char* parseEnv(void)
         return "KDE";
 
     if(getenv("GNOME_DESKTOP_SESSION_ID") != NULL)
-        return "Gnome";
+        return "GNOME";
 
     if(getenv("MATE_DESKTOP_SESSION_ID") != NULL)
         return "Mate";
@@ -71,11 +71,8 @@ static void applyPrettyNameIfWM(FFDisplayServerResult* result, const char* name)
         return;
 
     if(
-        ffStrEqualsIgnCase(name, "kwin_wayland") ||
-        ffStrEqualsIgnCase(name, "kwin_wayland_wrapper") ||
-        ffStrEqualsIgnCase(name, "kwin_x11") ||
-        ffStrEqualsIgnCase(name, "kwin_x11_wrapper") ||
         ffStrEqualsIgnCase(name, "kwin") ||
+        ffStrStartsWithIgnCase(name, "kwin_") ||
         ffStrEndsWithIgnCase(name, "-kwin_wayland") ||
         ffStrEndsWithIgnCase(name, "-kwin_x11")
     ) ffStrbufSetS(&result->wmPrettyName, FF_WM_PRETTY_KWIN);
@@ -86,7 +83,8 @@ static void applyPrettyNameIfWM(FFDisplayServerResult* result, const char* name)
         ffStrEqualsIgnCase(name, "Mutter")
     ) ffStrbufSetS(&result->wmPrettyName, FF_WM_PRETTY_MUTTER);
     else if(
-        ffStrEqualsIgnCase(name, "cinnamon-session") ||
+        ffStrEqualsIgnCase(name, "cinnamon") ||
+        ffStrStartsWithIgnCase(name, "cinnamon-") ||
         ffStrEqualsIgnCase(name, "Muffin") ||
         ffStrEqualsIgnCase(name, "Mutter (Muffin)")
     ) ffStrbufSetS(&result->wmPrettyName, FF_WM_PRETTY_MUFFIN);
@@ -164,7 +162,7 @@ static void applyPrettyNameIfDE(FFDisplayServerResult* result, const char* name)
     }
 
     else if(
-        ffStrEqualsIgnCase(name, "Gnome") ||
+        ffStrEqualsIgnCase(name, "GNOME") ||
         ffStrEqualsIgnCase(name, "ubuntu:GNOME") ||
         ffStrEqualsIgnCase(name, "ubuntu") ||
         ffStrEqualsIgnCase(name, "gnome-shell")
@@ -207,7 +205,7 @@ static void applyPrettyNameIfDE(FFDisplayServerResult* result, const char* name)
 
     else if(
         ffStrEqualsIgnCase(name, "LXQt") ||
-        ffStrEqualsIgnCase(name, "X-LXQT") ||
+        ffStrEqualsIgnCase(name, "X-LXQt") ||
         ffStrEqualsIgnCase(name, "lxqt-session")
     ) {
         ffStrbufSetS(&result->deProcessName, "lxqt-session");
@@ -303,6 +301,42 @@ static const char* getFromProcesses(FFDisplayServerResult* result)
         if(result->dePrettyName.length > 0 && result->wmPrettyName.length > 0)
             break;
     }
+#elif defined(__sun)
+    FF_AUTO_CLOSE_DIR DIR* procdir = opendir("/proc");
+    if(procdir == NULL)
+        return "opendir(\"/proc\") failed";
+
+    FF_STRBUF_AUTO_DESTROY procPath = ffStrbufCreateA(64);
+    ffStrbufAppendS(&procPath, "/proc/");
+
+    uint32_t procPathLength = procPath.length;
+
+    struct dirent* dirent;
+    while((dirent = readdir(procdir)) != NULL)
+    {
+        if (!ffCharIsDigit(dirent->d_name[0]))
+            continue;
+
+        ffStrbufAppendS(&procPath, dirent->d_name);
+        ffStrbufAppendS(&procPath, "/psinfo");
+        psinfo_t proc;
+        if (ffReadFileData(procPath.chars, sizeof(proc), &proc) == sizeof(proc))
+        {
+            ffStrbufSubstrBefore(&procPath, procPathLength);
+
+            if (proc.pr_uid != userId)
+                continue;
+
+            if(result->dePrettyName.length == 0)
+                applyPrettyNameIfDE(result, proc.pr_fname);
+
+            if(result->wmPrettyName.length == 0)
+                applyNameIfWM(result, proc.pr_fname);
+
+            if(result->dePrettyName.length > 0 && result->wmPrettyName.length > 0)
+                break;
+        }
+    }
 #else
     FF_AUTO_CLOSE_DIR DIR* procdir = opendir("/proc");
     if(procdir == NULL)
@@ -320,7 +354,7 @@ static const char* getFromProcesses(FFDisplayServerResult* result)
     while((dirent = readdir(procdir)) != NULL)
     {
         //Match only folders starting with a number (the pid folders)
-        if(dirent->d_type != DT_DIR || !isdigit(dirent->d_name[0]))
+        if(dirent->d_type != DT_DIR || !ffCharIsDigit(dirent->d_name[0]))
             continue;
 
         ffStrbufAppendS(&procPath, dirent->d_name);
